summaryrefslogtreecommitdiffstats
path: root/src/util/mmap_cache.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/util/mmap_cache.h')
-rw-r--r--src/util/mmap_cache.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/util/mmap_cache.h b/src/util/mmap_cache.h
index b5917b3c0..22c1ae62d 100644
--- a/src/util/mmap_cache.h
+++ b/src/util/mmap_cache.h
@@ -138,14 +138,15 @@ struct sss_mc_grp_data {
};
struct sss_mc_initgr_data {
- rel_ptr_t name; /* ptr to name string, rel. to struct base addr */
+ rel_ptr_t unique_name; /* ptr to unique name string, rel. to struct base addr */
+ rel_ptr_t name; /* ptr to raw name string, rel. to struct base addr */
rel_ptr_t strs; /* ptr to concatenation of all strings */
- uint32_t reserved;
uint32_t strs_len; /* length of strs */
uint32_t data_len; /* all initgroups data len */
uint32_t num_groups; /* number of groups */
uint32_t gids[0]; /* array of all groups
* string with name is stored after gids */
};
#pragma pack()
@@ -138,14 +138,15 @@ struct sss_mc_grp_data {
uint32_t num_groups; /* number of groups */
uint32_t gids[0]; /* array of all groups
- * string with name is stored after gids */
+ * string with name and unique_name is stored
+ * after gids */
};
#pragma pack()